<?php
/*!
  \file
  \brief ѥڡ

  \author Satofumi KAMIMURA

  $Id$

  \todo ;ϡ˾Хեޤľ
*/

require_once("includes/smartySettings.php");
$o_smarty = new SmartySettings();

require_once("includes/langUpload.php");
$user = new UserAuthorize();
$lang = new LangUpload();

if ($user->requireReload() || ! $user->isLogin() || ! $lang->isManager()) {
  header('Location: index.php');
  return;
}
if ($lang->handleAdminRequest()) {
  header('Location: forManager.php');
  return;
}

$o_smarty->assign('user', $user);
$o_smarty->assign('lang', $lang);
$o_smarty->display('forManager.tpl');
?>
